#!/usr/bin/env python3

import re

mappings = [
    ('.', '[.]'),
    (':', '[:]'),
    ('http', 'hxxp'),
    ('ftp', 'fxp'),
]

def defang(url):
    for k, v in mappings:
        url = re.sub(re.escape(k), v, url, flags=re.I)

    return url

def refang(url):
    for k, v in mappings:
        url = re.sub(re.escape(v), k, url, flags=re.I)

    return url



#!/usr/bin/env python3

import sys
import argparse

from defang import *

# Taken from: https://mail.python.org/pipermail/tutor/2003-November/026645.html
class Unbuffered(object):
   def __init__(self, stream):
       self.stream = stream
   def write(self, data):
       self.stream.write(data)
       self.stream.flush()
   def writelines(self, datas):
       self.stream.writelines(datas)
       self.stream.flush()
   def __getattr__(self, attr):
       return getattr(self.stream, attr)

# Remove buffering, processing large datasets eats memory otherwise
sys.stdout = Unbuffered(sys.stdout)

def parse_args(prog):
    parser = argparse.ArgumentParser(prog=prog)
    parser.add_argument('value', nargs='?', type=str, default=None,
                        help="Value to convert (can also be supplied on stdin)")

    return parser.parse_args()

def run(prog):
    args = parse_args(prog)

    urls = sys.stdin
    if args.value != None:
        urls = [args.value]

    for url in urls:
        url = url.rstrip()
        print(getattr(lib, prog)(url))

def defang():
    run('defang')

def refang():
    run('refang')




#!/usr/bin/env python3

import os
from setuptools import setup, find_packages

import defang

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
        name = 'pydefang',
        python_requires='>=3',
        version = defang.__version__,
        author = 'Yonathan Klijnsma',
        author_email = 'admin@0x3a.com',
        url = 'https://github.com/0x3a/pydefang',
        packages=find_packages(),
        include_package_data=True,
        description = 'A defang/refang utility written in Python.',
        long_description=read('README.md'),
        long_description_content_type='text/markdown',
        entry_points={
            'console_scripts': [
                'defang=defang:client.defang',
                'refang=defang:client.refang',
            ],
        },
        zip_safe=False,
     )
